@@ -13,7 +13,7 @@ from llvd.utils import clean_name
 
 
 class App:
-    def __init__(self, email, password, course_slug, resolution, caption):
+    def __init__(self, email, password, course_slug, resolution, caption, throttle):
 
         self.email = email
         self.password = password
@@ -26,6 +26,7 @@ class App:
         self.chapter_path = ""
         self.current_video_index = None
         self.current_video_name = ""
+        self.throttle = throttle
 
     def login(self, s, login_data):
         """
@@ -80,7 +81,7 @@ class App:
                             os.makedirs(f'{self.course_slug}')
                         self.download_entire_course()
 
-        except requests.exceptions.ConnectionError:
+        except ConnectionError:
             click.echo(click.style(f"Failed to connect", fg="red"))
 
     @staticmethod
@@ -108,6 +109,7 @@ class App:
             chapters = r.json()['elements'][0]['chapters']
             exercise_files = r.json()["elements"][0]["exerciseFileUrls"]
             chapters_index = 1
+            delay = self.throttle
 
             for chapter in chapters:
                 chapter_name = chapter["title"]
@@ -161,7 +163,7 @@ class App:
                                 click.style(f"Failed to download {video_name}", fg="red"))
                     else:
                         if clean_name(video_name) not in current_files:
-                            download_video(download_url, video_index, video_name, chapter_path)
+                            download_video(download_url, video_index, video_name, chapter_path, delay)
                             if subtitles is not None and self.caption:
                                 subtitle_lines = subtitles['lines']
                                 download_subtitles(
@@ -174,7 +176,10 @@ class App:
             if len(exercise_files) > 0:
                 download_exercises(exercise_files, course_path)
             click.echo("\nFinished, start learning! :)")
-
+        except requests.exceptions.TooManyRedirects:
+                    click.echo(click.style(f"Your cookie is expired", fg="red"))
+        except KeyError:
+                click.echo(click.style(f"That course is not found", fg="red"))
         except Exception as e:
             os.remove(f'{self.chapter_path}/{self.current_video_index:0=2d}-{clean_name(self.current_video_name)}.mp4')
             self.download_entire_course()
