@@ -3,3 +3,6 @@ login_url = "https://www.linkedin.com/checkpoint/lg/login"
 signup_url = "https://www.linkedin.com/checkpoint/lg/login-submit"
 course_url = "https://www.linkedin.com/learning-api/detailedCourses??fields=videos&addParagraphsToTranscript=true&courseSlug={0}&q=slugs"
 video_url = "https://www.linkedin.com/learning-api/detailedCourses?addParagraphsToTranscript=false&courseSlug={0}&q=slugs&resolution=_{1}&videoSlug={2}"
+
+email=""
+password=""
