@@ -1,5 +1,6 @@
 import re
-
+from random import randint
+from time import sleep
 
 def subtitles_time_format(ms):
     """
@@ -20,3 +21,19 @@ def clean_dir(course_name):
     course = course_name.lower().replace("c#", "c-sharp").replace(".net", "-dot-net")
     without_chars = re.sub(r'[\':)(,>.’/]', " ", course.strip()).replace("«", " ").replace("-»", " ").replace("»", " ").strip()
     return re.sub(r'(\s+)', "-", without_chars).replace("--", "-")
+
+def throttle( wait_time=None ):
+    ESC = '\x1b['
+    CLEAR_LINE = f'{ESC}2K'
+    CURSOR_HOME = f'{ESC}0G'
+    CURSOR_UP = f'{ESC}1A'
+    if wait_time is None:
+        print('utils.py#throttle - Error: missing throttle wait time.')
+        return
+    min_delay = wait_time[0]
+    max_delay = wait_time[1]
+    delay = randint(min_delay, max_delay)
+    print(f'Delaying for {delay} seconds.')
+    sleep(delay)
+    # clean up delay message
+    print( f'{CURSOR_UP}{CLEAR_LINE}{CURSOR_UP}{CURSOR_HOME}')
